# Source and destination file names
test_source = "latex_babel.rst"
test_destination = "latex_babel.tex"

# Keyword parameters passed to publish_file()
writer = "latex"
settings_overrides = {
    'legacy_column_widths': False,
    'use_latex_citations': True,
}
